@@ -26,7 +26,7 @@ protected:
 	bool _debug;
 
 	// Configuration access
-	Config _config;
+	buffy::Config _config;
 
 	type_signal_child_exit _signal_child_exit;
 
@@ -42,10 +42,10 @@ public:
 	static Environment& get() throw () { return *instance; }
 
 	// Get the configuration access object
-	Config& config() throw () { return _config; }
+	buffy::Config& config() throw () { return _config; }
 
 	// Scan folder locations for folders and send what is found to `cons'
-	void enumerateFolders(MailFolderConsumer& cons) throw (Exception);
+	void enumerateFolders(buffy::MailFolderConsumer& cons) throw (Exception);
 	
 	// Fork a process to run the command specified
 	void spawnCommand(const std::string& command) throw (SystemException);
