@@ -68,7 +68,7 @@ protected:
 	public:
 		EditorListModelColumns() { add(program); add(name); add(command); }
 
-		Gtk::TreeModelColumn<MailProgram> program;
+		Gtk::TreeModelColumn<buffy::MailProgram> program;
 		Gtk::TreeModelColumn<Glib::ustring> name;
 		Gtk::TreeModelColumn<Glib::ustring> command;
 	};
@@ -96,7 +96,7 @@ public:
 	void enact(BuffyWindow& buffy);
 	void reset();
 
-	void do_dialog(BuffyWindow& buffy);
+	void do_dialog(BuffyWindow* buffy);
 };
 
 // vim:set ts=4 sw=4:
